@@ -659,7 +659,7 @@ QIcon CertificateLineEdit::Private::statusIcon() const
 {
     switch (mStatus) {
     case Status::Empty:
-        return QIcon::fromTheme(QStringLiteral("emblem-unavailable"));
+        return {};
     case Status::Success:
         if (!mKey.isNull()) {
             return mIconProvider.icon(mKey);
@@ -674,13 +674,13 @@ QIcon CertificateLineEdit::Private::statusIcon() const
     case Status::None:
     case Status::Ambiguous:
         if (mEditingInProgress || mLocateJob) {
-            return QIcon::fromTheme(QStringLiteral("emblem-question"));
+            return QIcon::fromTheme(QStringLiteral("data-question"), QIcon::fromTheme(QStringLiteral("dialog-question")));
         } else {
-            return QIcon::fromTheme(QStringLiteral("emblem-error"));
+            return QIcon::fromTheme(QStringLiteral("data-error"));
         }
     case Status::Expired:
     case Status::Revoked:
-        return QIcon::fromTheme(QStringLiteral("emblem-error"));
+        return QIcon::fromTheme(QStringLiteral("data-error"));
     default:
         qDebug(KLEOPATRA_LOG) << __func__ << "Invalid status:" << static_cast<int>(mStatus);
         Q_ASSERT(!"Invalid status");
@@ -707,6 +707,8 @@ QString CertificateLineEdit::Private::statusToolTip() const
         }
     case Status::None:
     case Status::Ambiguous:
+    case Status::Expired:
+    case Status::Revoked:
         return errorMessage();
     default:
         qDebug(KLEOPATRA_LOG) << __func__ << "Invalid status:" << static_cast<int>(mStatus);
