@@ -18,6 +18,7 @@
 #include "view/htmllabel.h"
 #include "view/urllabel.h"
 
+#include <Libkleo/ApplicationPaletteWatcher>
 #include <Libkleo/AuditLogEntry>
 #include <Libkleo/AuditLogViewer>
 #include <Libkleo/Classify>
@@ -44,19 +45,24 @@ using namespace Kleo::Crypto::Gui;
 namespace
 {
 // TODO move out of here
-static QColor colorForVisualCode(Task::Result::VisualCode code)
+static KColorScheme::BackgroundRole colorForVisualCode(Task::Result::VisualCode code)
 {
     switch (code) {
     case Task::Result::AllGood:
-        return KColorScheme(QPalette::Active, KColorScheme::View).background(KColorScheme::PositiveBackground).color();
+        return KColorScheme::PositiveBackground;
     case Task::Result::Warning:
-        return KColorScheme(QPalette::Active, KColorScheme::View).background(KColorScheme::NormalBackground).color();
+        return KColorScheme::NormalBackground;
     case Task::Result::Danger:
-        return KColorScheme(QPalette::Active, KColorScheme::View).background(KColorScheme::NegativeBackground).color();
+        return KColorScheme::NegativeBackground;
     default:
-        return KColorScheme(QPalette::Active, KColorScheme::View).background(KColorScheme::NormalBackground).color();
+        return KColorScheme::NormalBackground;
     }
 }
+
+struct ResultItemData {
+    QPointer<QWidget> widget;
+    KColorScheme::BackgroundRole backgroundRole;
+};
 }
 
 class ResultItemWidget::Private
@@ -64,20 +70,19 @@ class ResultItemWidget::Private
     ResultItemWidget *const q;
 
 public:
-    explicit Private(const std::shared_ptr<const Task::Result> &result, ResultItemWidget *qq)
-        : q(qq)
-        , m_result(result)
-    {
-        Q_ASSERT(m_result);
-    }
+    Private(const std::shared_ptr<const Task::Result> &result, ResultItemWidget *qq);
 
     void slotLinkActivated(const QString &);
     void updateShowDetailsLabel();
+    void updateStyleSheets();
 
     void addIgnoreMDCButton(QBoxLayout *lay);
 
     void oneImportFinished();
 
+    ApplicationPaletteWatcher m_appPaletteWatcher;
+    QList<QPointer<QWidget>> m_mainStylesheetWidgets;
+    QList<ResultItemData> m_itemStylesheetWidgets;
     const std::shared_ptr<const Task::Result> m_result;
     UrlLabel *m_auditLogLabel = nullptr;
     QPushButton *m_closeButton = nullptr;
@@ -143,37 +148,53 @@ void ResultItemWidget::Private::updateShowDetailsLabel()
     m_auditLogLabel->setVisible(!auditLogUrl.isEmpty());
 }
 
-ResultItemWidget::ResultItemWidget(const std::shared_ptr<const Task::Result> &result, QWidget *parent, Qt::WindowFlags flags)
-    : QWidget(parent, flags)
-    , d(new Private(result, this))
+void ResultItemWidget::Private::updateStyleSheets()
 {
-    const auto color = KColorScheme(QPalette::Active, KColorScheme::View).background(KColorScheme::NormalBackground).color();
-    const QString styleSheet = SystemInfo::isHighContrastModeActive()
-        ? QStringLiteral(
-              "QFrame,QLabel { margin: 0px; }"
-              "QFrame#resultFrame{ border-style: solid; border-radius: 3px; border-width: 1px }"
-              "QLabel { padding: 5px; border-radius: 3px }")
-        : QStringLiteral(
-              "QFrame,QLabel { background-color: %1; margin: 0px; }"
-              "QFrame#resultFrame{ border-color: %2; border-style: solid; border-radius: 3px; border-width: 1px }"
-              "QLabel { padding: 5px; border-radius: 3px }")
-              .arg(color.name())
-              .arg(color.darker(150).name());
-    auto topLayout = new QVBoxLayout(this);
+    const QColor color = KColorScheme(QPalette::Active, KColorScheme::View).background(KColorScheme::NormalBackground).color();
+    const QColor borderColor = (color.lightnessF() > 0.5) ? color.darker(150) : color.lighter(150);
+    const QString styleSheet = QStringLiteral(
+                                   "QFrame,QLabel { background-color: %1; margin: 0px; }"
+                                   "QFrame#resultFrame{ border-color: %2; border-style: solid; border-radius: 3px; border-width: 1px }"
+                                   "QLabel { padding: 5px; border-radius: 3px }")
+                                   .arg(color.name())
+                                   .arg(borderColor.name());
+    for (auto &w : m_mainStylesheetWidgets) {
+        w->setStyleSheet(styleSheet);
+    }
+
+    for (auto &item : m_itemStylesheetWidgets) {
+        const QColor color = KColorScheme(QPalette::Active, KColorScheme::View).background(item.backgroundRole).color();
+        const QColor borderColor = (color.lightnessF() > 0.5) ? color.darker(150) : color.lighter(150);
+        const QString styleSheet = QStringLiteral(
+                                       "QFrame { background-color: %1; margin: 0px; }"
+                                       "QFrame { padding: 5px; border-radius: 3px; border-style: solid; border-width: 1px; border-color: %2; }")
+                                       .arg(color.name())
+                                       .arg(borderColor.name());
+        item.widget->setStyleSheet(styleSheet);
+    }
+}
+
+ResultItemWidget::Private::Private(const std::shared_ptr<const Task::Result> &result, ResultItemWidget *qq)
+    : q(qq)
+    , m_result(result)
+{
+    Q_ASSERT(m_result);
+
+    auto topLayout = new QVBoxLayout(q);
     auto frame = new QFrame;
     frame->setObjectName(QLatin1StringView("resultFrame"));
-    frame->setStyleSheet(styleSheet);
+    m_mainStylesheetWidgets.push_back(frame);
     topLayout->addWidget(frame);
     auto vlay = new QVBoxLayout(frame);
     auto layout = new QHBoxLayout();
     auto overview = new HtmlLabel;
     overview->setWordWrap(true);
-    overview->setHtml(d->m_result->overview());
-    overview->setStyleSheet(styleSheet);
-    setFocusPolicy(overview->focusPolicy());
-    setFocusProxy(overview);
-    connect(overview, &QLabel::linkActivated, this, [this](const auto &link) {
-        d->slotLinkActivated(link);
+    overview->setHtml(m_result->overview());
+    m_mainStylesheetWidgets.push_back(overview);
+    q->setFocusPolicy(overview->focusPolicy());
+    q->setFocusProxy(overview);
+    connect(overview, &QLabel::linkActivated, q, [this](const auto &link) {
+        slotLinkActivated(link);
     });
 
     layout->addWidget(overview);
@@ -182,16 +203,16 @@ ResultItemWidget::ResultItemWidget(const std::shared_ptr<const Task::Result> &re
     auto actionLayout = new QVBoxLayout;
     layout->addLayout(actionLayout);
 
-    d->addIgnoreMDCButton(actionLayout);
+    addIgnoreMDCButton(actionLayout);
 
-    d->m_auditLogLabel = new UrlLabel;
-    connect(d->m_auditLogLabel, &QLabel::linkActivated, this, [this](const auto &link) {
-        d->slotLinkActivated(link);
+    m_auditLogLabel = new UrlLabel;
+    connect(m_auditLogLabel, &QLabel::linkActivated, q, [this](const auto &link) {
+        slotLinkActivated(link);
     });
-    actionLayout->addWidget(d->m_auditLogLabel);
-    d->m_auditLogLabel->setStyleSheet(styleSheet);
+    actionLayout->addWidget(m_auditLogLabel);
+    m_mainStylesheetWidgets.push_back(m_auditLogLabel);
 
-    for (const auto &detail : d->m_result.get()->detailsList()) {
+    for (const auto &detail : m_result.get()->detailsList()) {
         auto frame = new QFrame;
         auto row = new QHBoxLayout(frame);
 
@@ -211,44 +232,43 @@ ResultItemWidget::ResultItemWidget(const std::shared_ptr<const Task::Result> &re
         detailsLabel->setWordWrap(true);
         detailsLabel->setHtml(detail.details);
         iconLabel->setStyleSheet(QStringLiteral("QLabel {border-width: 0; }"));
-        auto color = colorForVisualCode(detail.code);
-
-        const QString styleSheet = SystemInfo::isHighContrastModeActive()
-            ? QStringLiteral(
-                  "QFrame { margin: 0px; }"
-                  "QFrame { padding: 5px; border-radius: 3px }")
-            : QStringLiteral(
-                  "QFrame { background-color: %1; margin: 0px; }"
-                  "QFrame { padding: 5px; border-radius: 3px; border-style: solid; border-width: 1px; border-color: %2; }")
-                  .arg(color.name())
-                  .arg(color.darker(150).name());
-        frame->setStyleSheet(styleSheet);
+        m_itemStylesheetWidgets.push_back({frame, colorForVisualCode(detail.code)});
         detailsLabel->setStyleSheet(QStringLiteral("QLabel {border-width: 0; }"));
-        connect(detailsLabel, &QLabel::linkActivated, this, [this](const auto &link) {
-            d->slotLinkActivated(link);
+        connect(detailsLabel, &QLabel::linkActivated, q, [this](const auto &link) {
+            slotLinkActivated(link);
         });
 
         row->addWidget(detailsLabel, 1);
         vlay->addWidget(frame);
     }
 
-    d->m_showButton = new QPushButton;
-    d->m_showButton->setVisible(false);
-    connect(d->m_showButton, &QAbstractButton::clicked, this, &ResultItemWidget::showButtonClicked);
-    actionLayout->addWidget(d->m_showButton);
+    m_showButton = new QPushButton;
+    m_showButton->setVisible(false);
+    connect(m_showButton, &QAbstractButton::clicked, q, &ResultItemWidget::showButtonClicked);
+    actionLayout->addWidget(m_showButton);
 
-    d->m_closeButton = new QPushButton;
-    KGuiItem::assign(d->m_closeButton, KStandardGuiItem::close());
-    d->m_closeButton->setFixedSize(d->m_closeButton->sizeHint());
-    connect(d->m_closeButton, &QAbstractButton::clicked, this, &ResultItemWidget::closeButtonClicked);
-    actionLayout->addWidget(d->m_closeButton);
-    d->m_closeButton->setVisible(false);
+    m_closeButton = new QPushButton;
+    KGuiItem::assign(m_closeButton, KStandardGuiItem::close());
+    m_closeButton->setFixedSize(m_closeButton->sizeHint());
+    connect(m_closeButton, &QAbstractButton::clicked, q, &ResultItemWidget::closeButtonClicked);
+    actionLayout->addWidget(m_closeButton);
+    m_closeButton->setVisible(false);
 
     layout->setStretch(0, 1);
     actionLayout->addStretch(-1);
     vlay->addStretch(-1);
 
-    d->updateShowDetailsLabel();
+    updateShowDetailsLabel();
+    updateStyleSheets();
+    connect(&m_appPaletteWatcher, &ApplicationPaletteWatcher::paletteChanged, q, [this]() {
+        updateStyleSheets();
+    });
+}
+
+ResultItemWidget::ResultItemWidget(const std::shared_ptr<const Task::Result> &result, QWidget *parent, Qt::WindowFlags flags)
+    : QWidget(parent, flags)
+    , d(new Private(result, this))
+{
     setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Maximum);
 }
 
