@@ -28,7 +28,7 @@
 
 #include <Libkleo/Algorithm>
 #include <Libkleo/Compliance>
-#include <Libkleo/Dn>
+#include <Libkleo/DnAttributes>
 #include <Libkleo/Formatting>
 #include <Libkleo/GnuPG>
 #include <Libkleo/KeyCache>
@@ -45,6 +45,7 @@
 
 #include <gpgme.h>
 
+#include <QGpgME/DN>
 #include <QGpgME/Debug>
 #include <QGpgME/KeyListJob>
 #include <QGpgME/Protocol>
@@ -164,8 +165,8 @@ private:
                 gridLayout->addWidget(primaryUserIdField->label(), row, 0);
                 gridLayout->addLayout(primaryUserIdField->layout(), row, 1);
 
-                for (const auto &attribute : DN::attributeOrder()) {
-                    const auto attributeLabel = DN::attributeNameToLabel(attribute);
+                for (const auto &attribute : DNAttributes::order()) {
+                    const auto attributeLabel = DNAttributes::nameToLabel(attribute);
                     if (attributeLabel.isEmpty()) {
                         continue;
                     }
@@ -219,7 +220,7 @@ private:
                 row++;
                 smimeIssuerField = std::make_unique<InfoField>(i18n("Issuer:"), parent);
                 showIssuerCertificateAction = new QAction{parent};
-                showIssuerCertificateAction->setIcon(QIcon::fromTheme(QStringLiteral("dialog-information")));
+                showIssuerCertificateAction->setIcon(QIcon::fromTheme(QStringLiteral("info")));
                 showIssuerCertificateAction->setToolTip(i18nc("@info:tooltip", "Show the issuer certificate"));
                 Kleo::setAccessibleName(showIssuerCertificateAction, i18nc("@action:button", "Show certificate"));
                 smimeIssuerField->setAction(showIssuerCertificateAction);
@@ -401,7 +402,7 @@ void CertificateDetailsWidget::Private::setUpSMIMEAdressList()
     // add email address from primary user ID if not listed already as attribute field
     if (!emailField) {
         const auto ownerId = key.userID(0);
-        const Kleo::DN dn(ownerId.id());
+        const QGpgME::DN dn(ownerId.id());
         const QString dnEmail = dn[QStringLiteral("EMAIL")];
         if (!dnEmail.isEmpty()) {
             ui.smimeAddressList->addItem(dnEmail);
@@ -479,19 +480,19 @@ void CertificateDetailsWidget::Private::keysMayHaveChanged()
 QIcon CertificateDetailsWidget::Private::trustLevelIcon(const GpgME::UserID &uid) const
 {
     if (updateInProgress) {
-        return QIcon::fromTheme(QStringLiteral("emblem-question"));
+        return QIcon::fromTheme(QStringLiteral("data-question"));
     }
     switch (uid.validity()) {
     case GpgME::UserID::Unknown:
     case GpgME::UserID::Undefined:
-        return QIcon::fromTheme(QStringLiteral("emblem-question"));
+        return QIcon::fromTheme(QStringLiteral("data-question"));
     case GpgME::UserID::Never:
-        return QIcon::fromTheme(QStringLiteral("emblem-error"));
+        return QIcon::fromTheme(QStringLiteral("data-error"));
     case GpgME::UserID::Marginal:
-        return QIcon::fromTheme(QStringLiteral("emblem-warning"));
+        return QIcon::fromTheme(QStringLiteral("data-warning"));
     case GpgME::UserID::Full:
     case GpgME::UserID::Ultimate:
-        return QIcon::fromTheme(QStringLiteral("emblem-success"));
+        return QIcon::fromTheme(QStringLiteral("data-success"));
     }
     return {};
 }
@@ -560,7 +561,7 @@ void CertificateDetailsWidget::Private::setupPGPProperties()
     ui.primaryUserIdField->setVisible(true);
 }
 
-static QString formatDNToolTip(const Kleo::DN &dn)
+static QString formatDNToolTip(const QGpgME::DN &dn)
 {
     QString html = QStringLiteral("<table border=\"0\" cell-spacing=15>");
 
@@ -596,7 +597,7 @@ void CertificateDetailsWidget::Private::setupSMIMEProperties()
 
     ui.trustChainWidget->setKey(key);
     const auto ownerId = key.userID(0);
-    const Kleo::DN dn(ownerId.id());
+    const QGpgME::DN dn(ownerId.id());
 
     for (const auto &[attributeName, field] : ui.smimeAttributeFields) {
         const QString attributeValue = dn[attributeName];
@@ -606,7 +607,7 @@ void CertificateDetailsWidget::Private::setupSMIMEProperties()
     ui.smimeTrustLevelField->setIcon(trustLevelIcon(ownerId));
     ui.smimeTrustLevelField->setValue(trustLevelText(ownerId));
 
-    const Kleo::DN issuerDN(key.issuerName());
+    const QGpgME::DN issuerDN(key.issuerName());
     const QString issuerCN = issuerDN[QStringLiteral("CN")];
     const QString issuer = issuerCN.isEmpty() ? QString::fromUtf8(key.issuerName()) : issuerCN;
     ui.smimeIssuerField->setValue(issuer);
